@@ -43,7 +43,7 @@ mod traps;
 pub use crate::data_context::{DataContext, DataDescription, Init};
 pub use crate::module::{
     DataId, FuncId, FuncOrDataId, Linkage, Module, ModuleCompiledFunction, ModuleDeclarations,
-    ModuleError, ModuleResult, RelocRecord,
+    ModuleError, ModuleResult,
 };
 pub use crate::traps::TrapSite;
 
